core: Rename ServerCall to StreamServerCall.

This is part of an effort to clarify naming around contexts.  We are
going to rename ServerContext and security.Context to ServerCall and
security.Call respectively.  Now when people say "context" we will
know they mean context.T.

Change-Id: I447048f03d22ac685a7c092316b9a4e1505da59d
MultiPart: 2/4
diff --git a/lib/vdl/codegen/java/file_server_wrapper.go b/lib/vdl/codegen/java/file_server_wrapper.go
index e969966..f25a775 100644
--- a/lib/vdl/codegen/java/file_server_wrapper.go
+++ b/lib/vdl/codegen/java/file_server_wrapper.go
@@ -36,7 +36,7 @@
      */
     // TODO(spetrovic): Re-enable once we can import the new Signature classes.
     //@SuppressWarnings("unused")
-    //public io.v.v23.ipc.ServiceSignature signature(io.v.v23.ipc.ServerCall call) throws io.v.v23.verror.VException {
+    //public io.v.v23.ipc.ServiceSignature signature(io.v.v23.ipc.StreamServerCall call) throws io.v.v23.verror.VException {
     //    throw new io.v.v23.verror.VException("Signature method not yet supported for Java servers");
     //}
 
@@ -45,7 +45,7 @@
      * by this server.
      */
     @SuppressWarnings("unused")
-    public io.v.v23.vdl.VdlValue[] getMethodTags(final io.v.v23.ipc.ServerCall call, final java.lang.String method) throws io.v.v23.verror.VException {
+    public io.v.v23.vdl.VdlValue[] getMethodTags(final io.v.v23.ipc.StreamServerCall call, final java.lang.String method) throws io.v.v23.verror.VException {
         {{ range $methodName, $tags := .MethodTags }}
         if ("{{ $methodName }}".equals(method)) {
             try {
@@ -70,7 +70,7 @@
 
      {{/* Iterate over methods defined directly in the body of this server */}}
     {{ range $method := .Methods }}
-    {{ $method.AccessModifier }} {{ $method.RetType }} {{ $method.Name }}(final io.v.v23.ipc.ServerCall call{{ $method.DeclarationArgs }}) throws io.v.v23.verror.VException {
+    {{ $method.AccessModifier }} {{ $method.RetType }} {{ $method.Name }}(final io.v.v23.ipc.StreamServerCall call{{ $method.DeclarationArgs }}) throws io.v.v23.verror.VException {
         {{ if $method.IsStreaming }}
         final io.v.v23.vdl.Stream<{{ $method.SendType }}, {{ $method.RecvType }}> _stream = new io.v.v23.vdl.Stream<{{ $method.SendType }}, {{ $method.RecvType }}>() {
             @Override
@@ -96,7 +96,7 @@
 
 {{/* Iterate over methods from embeded servers and generate code to delegate the work */}}
 {{ range $eMethod := .EmbedMethods }}
-    {{ $eMethod.AccessModifier }} {{ $eMethod.RetType }} {{ $eMethod.Name }}(final io.v.v23.ipc.ServerCall call{{ $eMethod.DeclarationArgs }}) throws io.v.v23.verror.VException {
+    {{ $eMethod.AccessModifier }} {{ $eMethod.RetType }} {{ $eMethod.Name }}(final io.v.v23.ipc.StreamServerCall call{{ $eMethod.DeclarationArgs }}) throws io.v.v23.verror.VException {
         {{/* e.g. return this.stubArith.cosine(call, [args], options) */}}
         {{ if $eMethod.Returns }}return{{ end }}  this.{{ $eMethod.LocalWrapperVarName }}.{{ $eMethod.Name }}(call{{ $eMethod.CallingArgs }});
     }
diff --git a/runtimes/google/ipc/cancel_test.go b/runtimes/google/ipc/cancel_test.go
index e53500e..4bf2731 100644
--- a/runtimes/google/ipc/cancel_test.go
+++ b/runtimes/google/ipc/cancel_test.go
@@ -31,7 +31,7 @@
 	stop     func() error
 }
 
-func (c *canceld) Run(ctx ipc.ServerCall) error {
+func (c *canceld) Run(ctx ipc.StreamServerCall) error {
 	close(c.started)
 
 	client, err := InternalNewClient(c.sm, c.ns)
diff --git a/runtimes/google/ipc/full_test.go b/runtimes/google/ipc/full_test.go
index 5c5e3fb..aee21b9 100644
--- a/runtimes/google/ipc/full_test.go
+++ b/runtimes/google/ipc/full_test.go
@@ -136,7 +136,7 @@
 	return result, nil
 }
 
-func (*testServer) Stream(call ipc.ServerCall, arg string) (string, error) {
+func (*testServer) Stream(call ipc.StreamServerCall, arg string) (string, error) {
 	result := fmt.Sprintf("method:%q,suffix:%q,arg:%q", call.Method(), call.Suffix(), arg)
 	var u userType
 	var err error
@@ -152,7 +152,7 @@
 	return result, err
 }
 
-func (*testServer) Unauthorized(ipc.ServerCall) (string, error) {
+func (*testServer) Unauthorized(ipc.StreamServerCall) (string, error) {
 	return "UnauthorizedResult", nil
 }
 
@@ -188,7 +188,7 @@
 
 type dischargeServer struct{}
 
-func (*dischargeServer) Discharge(ctx ipc.ServerCall, cav security.Caveat, _ security.DischargeImpetus) (security.WireDischarge, error) {
+func (*dischargeServer) Discharge(ctx ipc.StreamServerCall, cav security.Caveat, _ security.DischargeImpetus) (security.WireDischarge, error) {
 	tp := cav.ThirdPartyDetails()
 	if tp == nil {
 		return nil, fmt.Errorf("discharger: %v does not represent a third-party caveat", cav)
@@ -1179,7 +1179,7 @@
 	}
 }
 
-func (s *cancelTestServer) CancelStreamReader(call ipc.ServerCall) error {
+func (s *cancelTestServer) CancelStreamReader(call ipc.StreamServerCall) error {
 	close(s.started)
 	var b []byte
 	if err := call.Recv(&b); err != io.EOF {
@@ -1193,7 +1193,7 @@
 // CancelStreamIgnorer doesn't read from it's input stream so all it's
 // buffers fill.  The intention is to show that call.Done() is closed
 // even when the stream is stalled.
-func (s *cancelTestServer) CancelStreamIgnorer(call ipc.ServerCall) error {
+func (s *cancelTestServer) CancelStreamIgnorer(call ipc.StreamServerCall) error {
 	close(s.started)
 	<-call.Context().Done()
 	close(s.cancelled)
@@ -1242,7 +1242,7 @@
 
 type streamRecvInGoroutineServer struct{ c chan error }
 
-func (s *streamRecvInGoroutineServer) RecvInGoroutine(call ipc.ServerCall) error {
+func (s *streamRecvInGoroutineServer) RecvInGoroutine(call ipc.StreamServerCall) error {
 	// Spawn a goroutine to read streaming data from the client.
 	go func() {
 		var i interface{}
diff --git a/runtimes/google/ipc/signature_test.go b/runtimes/google/ipc/signature_test.go
index 1b95c8c..1da3668 100644
--- a/runtimes/google/ipc/signature_test.go
+++ b/runtimes/google/ipc/signature_test.go
@@ -39,9 +39,9 @@
 func (sigImpl) Streaming0(_ *streamStringBool) error                       { panic("X") }
 func (sigImpl) Streaming1(_ *streamStringBool, _ int64) (float64, error)   { panic("X") }
 
-type streamStringBool struct{ ipc.ServerCall }
+type streamStringBool struct{ ipc.StreamServerCall }
 
-func (*streamStringBool) Init(ipc.ServerCall) { panic("X") }
+func (*streamStringBool) Init(ipc.StreamServerCall) { panic("X") }
 func (*streamStringBool) RecvStream() interface {
 	Advance() bool
 	Value() string
diff --git a/runtimes/google/ipc/simple_test.go b/runtimes/google/ipc/simple_test.go
index b393244..cf403f2 100644
--- a/runtimes/google/ipc/simple_test.go
+++ b/runtimes/google/ipc/simple_test.go
@@ -25,7 +25,7 @@
 	return "pong", nil
 }
 
-func (s *simple) Source(call ipc.ServerCall, start int) error {
+func (s *simple) Source(call ipc.StreamServerCall, start int) error {
 	i := start
 	backoff := 25 * time.Millisecond
 	for {
@@ -40,7 +40,7 @@
 	}
 }
 
-func (s *simple) Sink(call ipc.ServerCall) (int, error) {
+func (s *simple) Sink(call ipc.StreamServerCall) (int, error) {
 	i := 0
 	for {
 		if err := call.Recv(&i); err != nil {
@@ -52,7 +52,7 @@
 	}
 }
 
-func (s *simple) Inc(call ipc.ServerCall, inc int) (int, error) {
+func (s *simple) Inc(call ipc.StreamServerCall, inc int) (int, error) {
 	i := 0
 	for {
 		if err := call.Recv(&i); err != nil {
diff --git a/runtimes/google/rt/ipc_test.go b/runtimes/google/rt/ipc_test.go
index 6b582f7..951cc83 100644
--- a/runtimes/google/rt/ipc_test.go
+++ b/runtimes/google/rt/ipc_test.go
@@ -29,7 +29,7 @@
 
 type dischargeService struct{}
 
-func (dischargeService) Discharge(ctx ipc.ServerCall, cav security.Caveat, _ security.DischargeImpetus) (security.WireDischarge, error) {
+func (dischargeService) Discharge(ctx ipc.StreamServerCall, cav security.Caveat, _ security.DischargeImpetus) (security.WireDischarge, error) {
 	tp := cav.ThirdPartyDetails()
 	if tp == nil {
 		return nil, fmt.Errorf("discharger: not a third party caveat (%v)", cav)
diff --git a/services/identity/blesser/util_test.go b/services/identity/blesser/util_test.go
index 4a3590b..eef7803 100644
--- a/services/identity/blesser/util_test.go
+++ b/services/identity/blesser/util_test.go
@@ -8,7 +8,7 @@
 )
 
 type serverCall struct {
-	ipc.ServerCall
+	ipc.StreamServerCall
 	method        string
 	p             security.Principal
 	local, remote security.Blessings
diff --git a/services/mgmt/device/impl/proxy_invoker.go b/services/mgmt/device/impl/proxy_invoker.go
index e1dccde..37285e9 100644
--- a/services/mgmt/device/impl/proxy_invoker.go
+++ b/services/mgmt/device/impl/proxy_invoker.go
@@ -49,7 +49,7 @@
 	return
 }
 
-func (p *proxyInvoker) Invoke(method string, inCall ipc.ServerCall, argptrs []interface{}) (results []interface{}, err error) {
+func (p *proxyInvoker) Invoke(method string, inCall ipc.StreamServerCall, argptrs []interface{}) (results []interface{}, err error) {
 	// We accept any values as argument and pass them through to the remote
 	// server.
 	args := make([]interface{}, len(argptrs))
@@ -140,9 +140,9 @@
 // TODO(toddw): Expose a helper function that performs all error checking based
 // on reflection, to simplify the repeated logic processing results.
 func (p *proxyInvoker) Signature(ctx ipc.ServerContext) ([]signature.Interface, error) {
-	call, ok := ctx.(ipc.ServerCall)
+	call, ok := ctx.(ipc.StreamServerCall)
 	if !ok {
-		return nil, fmt.Errorf("couldn't upgrade ipc.ServerContext to ipc.ServerCall")
+		return nil, fmt.Errorf("couldn't upgrade ipc.ServerContext to ipc.StreamServerCall")
 	}
 	results, err := p.Invoke(ipc.ReservedSignature, call, nil)
 	if err != nil {
@@ -170,9 +170,9 @@
 
 func (p *proxyInvoker) MethodSignature(ctx ipc.ServerContext, method string) (signature.Method, error) {
 	empty := signature.Method{}
-	call, ok := ctx.(ipc.ServerCall)
+	call, ok := ctx.(ipc.StreamServerCall)
 	if !ok {
-		return empty, fmt.Errorf("couldn't upgrade ipc.ServerContext to ipc.ServerCall")
+		return empty, fmt.Errorf("couldn't upgrade ipc.ServerContext to ipc.StreamServerCall")
 	}
 	results, err := p.Invoke(ipc.ReservedMethodSignature, call, []interface{}{&method})
 	if err != nil {
diff --git a/services/wsprd/app/app_test.go b/services/wsprd/app/app_test.go
index 9cdeaf2..8f1175c 100644
--- a/services/wsprd/app/app_test.go
+++ b/services/wsprd/app/app_test.go
@@ -82,7 +82,7 @@
 	return a / b, nil
 }
 
-func (s simpleAdder) StreamingAdd(call ipc.ServerCall) (int32, error) {
+func (s simpleAdder) StreamingAdd(call ipc.StreamServerCall) (int32, error) {
 	total := int32(0)
 	var value int32
 	for err := call.Recv(&value); err == nil; err = call.Recv(&value) {
diff --git a/services/wsprd/browspr/browspr_test.go b/services/wsprd/browspr/browspr_test.go
index 5370832..cb3ac35 100644
--- a/services/wsprd/browspr/browspr_test.go
+++ b/services/wsprd/browspr/browspr_test.go
@@ -57,7 +57,7 @@
 
 type mockServer struct{}
 
-func (s mockServer) BasicCall(_ ipc.ServerCall, txt string) (string, error) {
+func (s mockServer) BasicCall(_ ipc.StreamServerCall, txt string) (string, error) {
 	return "[" + txt + "]", nil
 }
 
diff --git a/services/wsprd/ipc/server/dispatcher_test.go b/services/wsprd/ipc/server/dispatcher_test.go
index eaa7ab6..cb0ff73 100644
--- a/services/wsprd/ipc/server/dispatcher_test.go
+++ b/services/wsprd/ipc/server/dispatcher_test.go
@@ -33,7 +33,7 @@
 	return nil, nil, nil
 }
 
-func (mockInvoker) Invoke(string, ipc.ServerCall, []interface{}) ([]interface{}, error) {
+func (mockInvoker) Invoke(string, ipc.StreamServerCall, []interface{}) ([]interface{}, error) {
 	return nil, nil
 }
 
diff --git a/services/wsprd/ipc/server/invoker.go b/services/wsprd/ipc/server/invoker.go
index 92388c7..c58a40c 100644
--- a/services/wsprd/ipc/server/invoker.go
+++ b/services/wsprd/ipc/server/invoker.go
@@ -55,7 +55,7 @@
 }
 
 // Invoke implements the Invoker interface.
-func (i *invoker) Invoke(methodName string, call ipc.ServerCall, argptrs []interface{}) ([]interface{}, error) {
+func (i *invoker) Invoke(methodName string, call ipc.StreamServerCall, argptrs []interface{}) ([]interface{}, error) {
 	replychan := i.invokeFunc(methodName, argptrs, call)
 
 	// Wait for the result
diff --git a/services/wsprd/ipc/server/server.go b/services/wsprd/ipc/server/server.go
index c3dc133..16b4250 100644
--- a/services/wsprd/ipc/server/server.go
+++ b/services/wsprd/ipc/server/server.go
@@ -125,10 +125,10 @@
 
 // remoteInvokeFunc is a type of function that can invoke a remote method and
 // communicate the result back via a channel to the caller
-type remoteInvokeFunc func(methodName string, args []interface{}, call ipc.ServerCall) <-chan *lib.ServerRPCReply
+type remoteInvokeFunc func(methodName string, args []interface{}, call ipc.StreamServerCall) <-chan *lib.ServerRPCReply
 
 func (s *Server) createRemoteInvokerFunc(handle int32) remoteInvokeFunc {
-	return func(methodName string, args []interface{}, call ipc.ServerCall) <-chan *lib.ServerRPCReply {
+	return func(methodName string, args []interface{}, call ipc.StreamServerCall) <-chan *lib.ServerRPCReply {
 		securityContext := s.convertSecurityContext(call, true)
 
 		flow := s.helper.CreateNewFlow(s, call)
diff --git a/tools/principal/main.go b/tools/principal/main.go
index 2d22948..1ade634 100644
--- a/tools/principal/main.go
+++ b/tools/principal/main.go
@@ -853,7 +853,7 @@
 	token     string
 }
 
-func (r *recvBlessingsService) Grant(call ipc.ServerCall, token string) error {
+func (r *recvBlessingsService) Grant(call ipc.StreamServerCall, token string) error {
 	b := call.Blessings()
 	if b.IsZero() {
 		return fmt.Errorf("no blessings granted by sender")
diff --git a/lib/vdl/codegen/golang/gen.go b/lib/vdl/codegen/golang/gen.go
index 5e3c77a..321b7e8 100644
--- a/lib/vdl/codegen/golang/gen.go
+++ b/lib/vdl/codegen/golang/gen.go
@@ -741,17 +741,17 @@
 	{{$serverStream}}
 }
 
 // {{$serverContextStub}} is a wrapper that converts ipc.ServerCall into
 // a typesafe stub that implements {{$serverContext}}.
 type {{$serverContextStub}} struct {
-	{{$ipc_}}ServerCall{{if $method.InStream}}
+	{{$ipc_}}StreamServerCall{{if $method.InStream}}
 	valRecv {{typeGo $data $method.InStream}}
 	errRecv error{{end}}
 }
 
-// Init initializes {{$serverContextStub}} from ipc.ServerCall.
-func (s *{{$serverContextStub}}) Init(call {{$ipc_}}ServerCall) {
-	s.ServerCall = call
+// Init initializes {{$serverContextStub}} from ipc.StreamServerCall.
+func (s *{{$serverContextStub}}) Init(call {{$ipc_}}StreamServerCall) {
+	s.StreamServerCall = call
 }
 
 {{if $method.InStream}}// RecvStream returns the receiver side of the {{$iface.Name}}.{{$method.Name}} server stream.
@@ -741,17 +741,17 @@
 }
 
-// {{$serverContextStub}} is a wrapper that converts ipc.ServerCall into
+// {{$serverContextStub}} is a wrapper that converts ipc.StreamServerCall into
 // a typesafe stub that implements {{$serverContext}}.
 type {{$serverContextStub}} struct {
diff --git a/lib/vdl/testdata/arith/arith.vdl.go b/lib/vdl/testdata/arith/arith.vdl.go
index 01f79ea..1e279d6 100644
--- a/lib/vdl/testdata/arith/arith.vdl.go
+++ b/lib/vdl/testdata/arith/arith.vdl.go
@@ -586,15 +586,15 @@
 	ArithCountServerStream
 }
 
 // ArithCountContextStub is a wrapper that converts ipc.ServerCall into
 // a typesafe stub that implements ArithCountContext.
 type ArithCountContextStub struct {
-	ipc.ServerCall
+	ipc.StreamServerCall
 }
 
-// Init initializes ArithCountContextStub from ipc.ServerCall.
-func (s *ArithCountContextStub) Init(call ipc.ServerCall) {
-	s.ServerCall = call
+// Init initializes ArithCountContextStub from ipc.StreamServerCall.
+func (s *ArithCountContextStub) Init(call ipc.StreamServerCall) {
+	s.StreamServerCall = call
 }
 
 // SendStream returns the send side of the Arith.Count server stream.
@@ -641,17 +641,17 @@
 	ArithStreamingAddServerStream
 }
 
 // ArithStreamingAddContextStub is a wrapper that converts ipc.ServerCall into
 // a typesafe stub that implements ArithStreamingAddContext.
 type ArithStreamingAddContextStub struct {
-	ipc.ServerCall
+	ipc.StreamServerCall
 	valRecv int32
 	errRecv error
 }
 
-// Init initializes ArithStreamingAddContextStub from ipc.ServerCall.
-func (s *ArithStreamingAddContextStub) Init(call ipc.ServerCall) {
-	s.ServerCall = call
+// Init initializes ArithStreamingAddContextStub from ipc.StreamServerCall.
+func (s *ArithStreamingAddContextStub) Init(call ipc.StreamServerCall) {
+	s.StreamServerCall = call
 }
 
 // RecvStream returns the receiver side of the Arith.StreamingAdd server stream.
@@ -586,15 +586,15 @@
 }
 
-// ArithCountContextStub is a wrapper that converts ipc.ServerCall into
+// ArithCountContextStub is a wrapper that converts ipc.StreamServerCall into
 // a typesafe stub that implements ArithCountContext.
 type ArithCountContextStub struct {
@@ -641,17 +641,17 @@
 }
 
-// ArithStreamingAddContextStub is a wrapper that converts ipc.ServerCall into
+// ArithStreamingAddContextStub is a wrapper that converts ipc.StreamServerCall into
 // a typesafe stub that implements ArithStreamingAddContext.
 type ArithStreamingAddContextStub struct {
diff --git a/lib/vdl/testdata/base/base.vdl.go b/lib/vdl/testdata/base/base.vdl.go
index b2581db..a941afb 100644
--- a/lib/vdl/testdata/base/base.vdl.go
+++ b/lib/vdl/testdata/base/base.vdl.go
@@ -974,15 +974,15 @@
 	ServiceAMethodA3ServerStream
 }
 
 // ServiceAMethodA3ContextStub is a wrapper that converts ipc.ServerCall into
 // a typesafe stub that implements ServiceAMethodA3Context.
 type ServiceAMethodA3ContextStub struct {
-	ipc.ServerCall
+	ipc.StreamServerCall
 }
 
-// Init initializes ServiceAMethodA3ContextStub from ipc.ServerCall.
-func (s *ServiceAMethodA3ContextStub) Init(call ipc.ServerCall) {
-	s.ServerCall = call
+// Init initializes ServiceAMethodA3ContextStub from ipc.StreamServerCall.
+func (s *ServiceAMethodA3ContextStub) Init(call ipc.StreamServerCall) {
+	s.StreamServerCall = call
 }
 
 // SendStream returns the send side of the ServiceA.MethodA3 server stream.
@@ -1029,17 +1029,17 @@
 	ServiceAMethodA4ServerStream
 }
 
 // ServiceAMethodA4ContextStub is a wrapper that converts ipc.ServerCall into
 // a typesafe stub that implements ServiceAMethodA4Context.
 type ServiceAMethodA4ContextStub struct {
-	ipc.ServerCall
+	ipc.StreamServerCall
 	valRecv int32
 	errRecv error
 }
 
-// Init initializes ServiceAMethodA4ContextStub from ipc.ServerCall.
-func (s *ServiceAMethodA4ContextStub) Init(call ipc.ServerCall) {
-	s.ServerCall = call
+// Init initializes ServiceAMethodA4ContextStub from ipc.StreamServerCall.
+func (s *ServiceAMethodA4ContextStub) Init(call ipc.StreamServerCall) {
+	s.StreamServerCall = call
 }
 
 // RecvStream returns the receiver side of the ServiceA.MethodA4 server stream.
@@ -974,15 +974,15 @@
 }
 
-// ServiceAMethodA3ContextStub is a wrapper that converts ipc.ServerCall into
+// ServiceAMethodA3ContextStub is a wrapper that converts ipc.StreamServerCall into
 // a typesafe stub that implements ServiceAMethodA3Context.
 type ServiceAMethodA3ContextStub struct {
@@ -1029,17 +1029,17 @@
 }
 
-// ServiceAMethodA4ContextStub is a wrapper that converts ipc.ServerCall into
+// ServiceAMethodA4ContextStub is a wrapper that converts ipc.StreamServerCall into
 // a typesafe stub that implements ServiceAMethodA4Context.
 type ServiceAMethodA4ContextStub struct {
diff --git a/runtimes/google/ipc/benchmark/benchmark.vdl.go b/runtimes/google/ipc/benchmark/benchmark.vdl.go
index 11c6e5c..1006154 100644
--- a/runtimes/google/ipc/benchmark/benchmark.vdl.go
+++ b/runtimes/google/ipc/benchmark/benchmark.vdl.go
@@ -296,17 +296,17 @@
 	BenchmarkEchoStreamServerStream
 }
 
 // BenchmarkEchoStreamContextStub is a wrapper that converts ipc.ServerCall into
 // a typesafe stub that implements BenchmarkEchoStreamContext.
 type BenchmarkEchoStreamContextStub struct {
-	ipc.ServerCall
+	ipc.StreamServerCall
 	valRecv []byte
 	errRecv error
 }
 
-// Init initializes BenchmarkEchoStreamContextStub from ipc.ServerCall.
-func (s *BenchmarkEchoStreamContextStub) Init(call ipc.ServerCall) {
-	s.ServerCall = call
+// Init initializes BenchmarkEchoStreamContextStub from ipc.StreamServerCall.
+func (s *BenchmarkEchoStreamContextStub) Init(call ipc.StreamServerCall) {
+	s.StreamServerCall = call
 }
 
 // RecvStream returns the receiver side of the Benchmark.EchoStream server stream.
@@ -296,17 +296,17 @@
 }
 
-// BenchmarkEchoStreamContextStub is a wrapper that converts ipc.ServerCall into
+// BenchmarkEchoStreamContextStub is a wrapper that converts ipc.StreamServerCall into
 // a typesafe stub that implements BenchmarkEchoStreamContext.
 type BenchmarkEchoStreamContextStub struct {
diff --git a/runtimes/google/ipc/reserved.go b/runtimes/google/ipc/reserved.go
index 2ff4003..ef16e35 100644
--- a/runtimes/google/ipc/reserved.go
+++ b/runtimes/google/ipc/reserved.go
@@ -143,7 +143,7 @@
 	return invoker.MethodSignature(ctx, ctx.Method())
 }
 
-func (r *reservedMethods) Glob(ctx ipc.ServerCall, pattern string) error {
+func (r *reservedMethods) Glob(ctx ipc.StreamServerCall, pattern string) error {
 	// Copy the original call to shield ourselves from changes the flowServer makes.
 	glob := globInternal{r.dispNormal, r.dispReserved, ctx.Suffix()}
 	return glob.Glob(copyMutableCall(ctx), pattern)
@@ -313,7 +313,7 @@
 
 // copyMutableCall returns a new mutableCall copied from call.  Changes to the
 // original call don't affect the mutable fields in the returned object.
-func copyMutableCall(call ipc.ServerCall) *mutableCall {
+func copyMutableCall(call ipc.StreamServerCall) *mutableCall {
 	return &mutableCall{Stream: call, mutableContext: copyMutableContext(call)}
 }
 
@@ -327,7 +327,7 @@
 	return c
 }
 
 // mutableCall provides a mutable implementation of ipc.ServerCall, useful for
 // our various special-cased reserved methods.
 type mutableCall struct {
 	ipc.Stream
@@ -327,7 +327,7 @@
 }
 
-// mutableCall provides a mutable implementation of ipc.ServerCall, useful for
+// mutableCall provides a mutable implementation of ipc.StreamServerCall, useful for
 // our various special-cased reserved methods.
 type mutableCall struct {
diff --git a/runtimes/google/ipc/stress/stress.vdl.go b/runtimes/google/ipc/stress/stress.vdl.go
index ace7d6a..6ba74b5 100644
--- a/runtimes/google/ipc/stress/stress.vdl.go
+++ b/runtimes/google/ipc/stress/stress.vdl.go
@@ -371,17 +371,17 @@
 	StressSumStreamServerStream
 }
 
 // StressSumStreamContextStub is a wrapper that converts ipc.ServerCall into
 // a typesafe stub that implements StressSumStreamContext.
 type StressSumStreamContextStub struct {
-	ipc.ServerCall
+	ipc.StreamServerCall
 	valRecv Arg
 	errRecv error
 }
 
-// Init initializes StressSumStreamContextStub from ipc.ServerCall.
-func (s *StressSumStreamContextStub) Init(call ipc.ServerCall) {
-	s.ServerCall = call
+// Init initializes StressSumStreamContextStub from ipc.StreamServerCall.
+func (s *StressSumStreamContextStub) Init(call ipc.StreamServerCall) {
+	s.StreamServerCall = call
 }
 
 // RecvStream returns the receiver side of the Stress.SumStream server stream.
@@ -371,17 +371,17 @@
 }
 
-// StressSumStreamContextStub is a wrapper that converts ipc.ServerCall into
+// StressSumStreamContextStub is a wrapper that converts ipc.StreamServerCall into
 // a typesafe stub that implements StressSumStreamContext.
 type StressSumStreamContextStub struct {
diff --git a/security/agent/server/wire.vdl.go b/security/agent/server/wire.vdl.go
index 27d61aa..1d0156b 100644
--- a/security/agent/server/wire.vdl.go
+++ b/security/agent/server/wire.vdl.go
@@ -633,15 +633,15 @@
 	AgentNotifyWhenChangedServerStream
 }
 
 // AgentNotifyWhenChangedContextStub is a wrapper that converts ipc.ServerCall into
 // a typesafe stub that implements AgentNotifyWhenChangedContext.
 type AgentNotifyWhenChangedContextStub struct {
-	ipc.ServerCall
+	ipc.StreamServerCall
 }
 
-// Init initializes AgentNotifyWhenChangedContextStub from ipc.ServerCall.
-func (s *AgentNotifyWhenChangedContextStub) Init(call ipc.ServerCall) {
-	s.ServerCall = call
+// Init initializes AgentNotifyWhenChangedContextStub from ipc.StreamServerCall.
+func (s *AgentNotifyWhenChangedContextStub) Init(call ipc.StreamServerCall) {
+	s.StreamServerCall = call
 }
 
 // SendStream returns the send side of the Agent.NotifyWhenChanged server stream.
@@ -633,15 +633,15 @@
 }
 
-// AgentNotifyWhenChangedContextStub is a wrapper that converts ipc.ServerCall into
+// AgentNotifyWhenChangedContextStub is a wrapper that converts ipc.StreamServerCall into
 // a typesafe stub that implements AgentNotifyWhenChangedContext.
 type AgentNotifyWhenChangedContextStub struct {
diff --git a/services/wsprd/namespace/namespace.vdl.go b/services/wsprd/namespace/namespace.vdl.go
index 1b2fd9a..0fa1062 100644
--- a/services/wsprd/namespace/namespace.vdl.go
+++ b/services/wsprd/namespace/namespace.vdl.go
@@ -630,15 +630,15 @@
 	NamespaceGlobServerStream
 }
 
 // NamespaceGlobContextStub is a wrapper that converts ipc.ServerCall into
 // a typesafe stub that implements NamespaceGlobContext.
 type NamespaceGlobContextStub struct {
-	ipc.ServerCall
+	ipc.StreamServerCall
 }
 
-// Init initializes NamespaceGlobContextStub from ipc.ServerCall.
-func (s *NamespaceGlobContextStub) Init(call ipc.ServerCall) {
-	s.ServerCall = call
+// Init initializes NamespaceGlobContextStub from ipc.StreamServerCall.
+func (s *NamespaceGlobContextStub) Init(call ipc.StreamServerCall) {
+	s.StreamServerCall = call
 }
 
 // SendStream returns the send side of the Namespace.Glob server stream.
@@ -630,15 +630,15 @@
 }
 
-// NamespaceGlobContextStub is a wrapper that converts ipc.ServerCall into
+// NamespaceGlobContextStub is a wrapper that converts ipc.StreamServerCall into
 // a typesafe stub that implements NamespaceGlobContext.
 type NamespaceGlobContextStub struct {
diff --git a/tools/vrpc/test_base/test_base.vdl.go b/tools/vrpc/test_base/test_base.vdl.go
index 3db3c6d..db2a89a 100644
--- a/tools/vrpc/test_base/test_base.vdl.go
+++ b/tools/vrpc/test_base/test_base.vdl.go
@@ -655,15 +655,15 @@
 	TypeTesterZStreamServerStream
 }
 
 // TypeTesterZStreamContextStub is a wrapper that converts ipc.ServerCall into
 // a typesafe stub that implements TypeTesterZStreamContext.
 type TypeTesterZStreamContextStub struct {
-	ipc.ServerCall
+	ipc.StreamServerCall
 }
 
-// Init initializes TypeTesterZStreamContextStub from ipc.ServerCall.
-func (s *TypeTesterZStreamContextStub) Init(call ipc.ServerCall) {
-	s.ServerCall = call
+// Init initializes TypeTesterZStreamContextStub from ipc.StreamServerCall.
+func (s *TypeTesterZStreamContextStub) Init(call ipc.StreamServerCall) {
+	s.StreamServerCall = call
 }
 
 // SendStream returns the send side of the TypeTester.ZStream server stream.
@@ -655,15 +655,15 @@
 }
 
-// TypeTesterZStreamContextStub is a wrapper that converts ipc.ServerCall into
+// TypeTesterZStreamContextStub is a wrapper that converts ipc.StreamServerCall into
 // a typesafe stub that implements TypeTesterZStreamContext.
 type TypeTesterZStreamContextStub struct {